@@ -16,10 +16,11 @@ def register():
         SaleOpportunity,
         SaleOpportunityLine,
         SaleOpportunityEmployee,
-        OpenSaleOpportunityEmployeeStart,
+        SaleOpportunityEmployeeContext,
         SaleOpportunityMonthly,
         SaleOpportunityEmployeeMonthly,
         Configuration,
+        ConfigurationSequence,
         Sale,
         Party,
         Address,
@@ -31,5 +32,5 @@ def register():
         Employee,
         module='sale_opportunity', type_='model')
     Pool.register(
-        OpenSaleOpportunityEmployee,
+        PartyReplace,
         module='sale_opportunity', type_='wizard')
