@@ -10,7 +10,6 @@ from sql.functions import Extract
 
 from trytond.model import ModelView, ModelSQL, Workflow, fields, \
     sequence_ordered
-from trytond import backend
 from trytond.pyson import Eval, In, If, Get, Bool
 from trytond.transaction import Transaction
 from trytond.pool import Pool
@@ -111,11 +110,10 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
         pool = Pool()
         Sale = pool.get('sale.sale')
         cursor = Transaction().connection.cursor()
-        TableHandler = backend.get('TableHandler')
         sql_table = cls.__table__()
         sale = Sale.__table__()
 
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
         number_exists = table.column_exist('number')
 
         # Migration from 3.8: rename reference into number
@@ -124,17 +122,7 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
             number_exists = True
 
         super(SaleOpportunity, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
-
-        # Migration from 2.8: make party not required and add number as
-        # required
-        table.not_null_action('party', action='remove')
-        if not number_exists:
-            cursor.execute(*sql_table.update(
-                    columns=[sql_table.number],
-                    values=[sql_table.id],
-                    where=sql_table.number == Null))
-            table.not_null_action('number', action='add')
+        table = cls.__table_handler__(module_name)
 
         # Migration from 3.4: replace sale by origin
         if table.column_exist('sale'):
@@ -146,7 +134,7 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
                         columns=[sale.origin],
                         values=['%s,%s' % (cls.__name__, id_)],
                         where=sale.id == sale_id))
-            table.drop_column('sale', exception=True)
+            table.drop_column('sale')
 
         # Migration from 4.0: change probability into conversion probability
         if table.column_exist('probability'):
@@ -188,19 +176,24 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
                     'invisible': ~Eval('state').in_(
                         ['cancelled', 'lost', 'opportunity']),
                     'icon': If(Eval('state').in_(['cancelled', 'lost']),
-                        'tryton-clear', 'tryton-go-previous'),
+                        'tryton-undo', 'tryton-back'),
+                    'depends': ['state'],
                     },
                 'opportunity': {
                     'invisible': ~Eval('state').in_(['lead']),
+                    'depends': ['state'],
                     },
                 'convert': {
                     'invisible': ~Eval('state').in_(['opportunity']),
+                    'depends': ['state'],
                     },
                 'lost': {
                     'invisible': ~Eval('state').in_(['lead', 'opportunity']),
+                    'depends': ['state'],
                     },
                 'cancel': {
                     'invisible': ~Eval('state').in_(['lead', 'opportunity']),
+                    'depends': ['state'],
                     },
                 })
 
@@ -250,7 +243,8 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
     def copy(cls, opportunities, default=None):
         if default is None:
             default = {}
-        default = default.copy()
+        else:
+            default = default.copy()
         default.setdefault('number', None)
         default.setdefault('sales', None)
         return super(SaleOpportunity, cls).copy(opportunities, default=default)
@@ -346,7 +340,7 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
     def won(cls, opportunities):
         pool = Pool()
         Date = pool.get('ir.date')
-        cls.write(filter(lambda o: o.is_forecast, opportunities), {
+        cls.write([o for o in opportunities if o.is_forecast], {
                 'end_date': Date.today(),
                 'state': 'won',
                 })
@@ -356,7 +350,7 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
     @Workflow.transition('lost')
     def lost(cls, opportunities):
         Date = Pool().get('ir.date')
-        cls.write(filter(lambda o: o.is_forecast, opportunities), {
+        cls.write([o for o in opportunities if o.is_forecast], {
                 'end_date': Date.today(),
                 'state': 'lost',
                 })
@@ -366,7 +360,7 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
     @Workflow.transition('cancelled')
     def cancel(cls, opportunities):
         Date = Pool().get('ir.date')
-        cls.write(filter(lambda o: o.is_forecast, opportunities), {
+        cls.write([o for o in opportunities if o.is_forecast], {
                 'end_date': Date.today(),
                 })
 
@@ -462,16 +456,6 @@ class SaleOpportunityLine(sequence_ordered(), ModelSQL, ModelView):
 
     del _states, _depends
 
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        table = TableHandler(cls, module_name)
-
-        super(SaleOpportunityLine, cls).__register__(module_name)
-
-        # Migration from 2.4: drop required on sequence
-        table.not_null_action('sequence', action='remove')
-
     @fields.depends('opportunity', '_parent_opportunity.state')
     def on_change_with_opportunity_state(self, name=None):
         if self.opportunity:
